OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Sötét téma",
    "Enable dark theme" : "Sötét téma engedélyezése",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "A sötét téma csökkenti a szemek terhelését az átlagos fényesség és fényerő csökkentésével. Még mindig fejlesztés alatt áll, így jelentse ha problémát talál.",
    "High contrast mode" : "Magas kontrasztú mód",
    "Enable high contrast mode" : "Magas kontrasztú mód engedélyezése",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "A magas kontrasztú téma megkönnyíti a navigációt. A képi minőség csökken, de az olvashatóság javul.",
    "Dyslexia font" : "Diszlexia betűkészlet",
    "Enable dyslexia font" : "Diszlexia betűkészlet engedélyezése",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Az OpenDyslexic egy szabad betűkészlet, amely egyes, diszlexia által okozott, gyakori olvasási hibák csökkentésére lett tervezve.",
    "Accessibility" : "Akadálymentesítés",
    "Accessibility options for nextcloud" : "Akadálymentesítési lehetőségek a Nextcloudhoz",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Több akadálymentesítési lehetőséget biztosít, hogy megkönnyítse a Nextcloud használatát",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Az akadálymentesítés fontos számunka. A webes szabványokat követjük, és ellenőrizzük, hogy minden használható egér nélkül, illetve akadálymentesítési technológiákkal, például képernyőolvasókkal. Arra törekszünk, hogy a {guidelines}Webes tartalomra vonatkozó akadálymentesítési irányelvek{linkend} 2.1-es változatának AA szinten, a magas kontrasztú témával pedig AAA szinten megfeleljünk.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ha problémákat tapasztal, jelentse a {issuetracker}hibakövetőnkben{linkend}. És ha segíteni szeretne, csatlakozzon a {designteam}dizájn csapatunkhoz{linkend}!"
},
"nplurals=2; plural=(n != 1);");
